summaryrefslogtreecommitdiff
path: root/storage/connect/tabxml.cpp
diff options
context:
space:
mode:
authorOlivier Bertrand <bertrandop@gmail.com>2013-02-20 01:30:37 +0100
committerOlivier Bertrand <bertrandop@gmail.com>2013-02-20 01:30:37 +0100
commitc448839c4fd3d097d0d7271ce4752b28d6f6e1f5 (patch)
tree41a0bc55190848d71f649b1aee3133fbc388d992 /storage/connect/tabxml.cpp
parent2f48842a0fd61cfd3268293e64077bb7773dbea1 (diff)
downloadmariadb-git-c448839c4fd3d097d0d7271ce4752b28d6f6e1f5.tar.gz
- Fix crash on making an XML table with encoding=XXX
- Set parameters so libxml2 does not anymore add extra characters when retrieving several subnodes of a node. - Make a CONNECT file header (was PlugDB) modified: storage/connect/domdoc.cpp storage/connect/libdoc.cpp storage/connect/tabxml.cpp - Change the version number modified: storage/connect/ha_connect.cc - Begin eliminate use of libmysql functions in MYSQL table type Not finished yet modified: storage/connect/myconn.cpp storage/connect/myconn.h
Diffstat (limited to 'storage/connect/tabxml.cpp')
-rw-r--r--storage/connect/tabxml.cpp14
1 files changed, 11 insertions, 3 deletions
diff --git a/storage/connect/tabxml.cpp b/storage/connect/tabxml.cpp
index 25d7e03073b..ea0d48dbddb 100644
--- a/storage/connect/tabxml.cpp
+++ b/storage/connect/tabxml.cpp
@@ -496,8 +496,9 @@ bool TDBXML::Initialize(PGLOBAL g)
goto error;
} // endif NewDoc
- // Add a PlugDB comment node
- sprintf(buf, MSG(CREATED_PLUGDB), version);
+ // Add a CONNECT comment node
+// sprintf(buf, MSG(CREATED_PLUGDB), version);
+ sprintf(buf, " Created by CONNECT %s ", version);
Docp->AddComment(g, buf);
if (XmlDB) {
@@ -914,7 +915,14 @@ void TDBXML::CloseDB(PGLOBAL g)
TabNode->AddText(g, "\n");
// Save the modified document
- int rc = Docp->DumpDoc(g, filename);
+ if (Docp->DumpDoc(g, filename)) {
+ PushWarning(g, this);
+ Docp->CloseDoc(g, To_Xb);
+
+ // This causes a crash in Diagnostics_area::set_error_status
+// longjmp(g->jumper[g->jump_level], TYPE_AM_XML);
+ } // endif DumpDoc
+
} // endif Changed
// Free the document and terminate XML processing